{% load wagtailcore_tags %}

<div class="row">
    <div class="box">
        <div class="col-lg-12">
            <hr>
            <h2 class="intro-text text-center">
                <strong>{{ value.heading}}</strong>
            </h2>
            <hr>
        </div>

        {% if value.paragraph %}
            <div class="col-lg-12">
                {{ value.paragraph }}
            </div>
        {% endif %}

        {% include_block value.bound_blocks.files %}
    </div>
</div>
