<div class="row">
    <div class="box">
        <div class="col-lg-12">
            <hr>
            <h2 class="intro-text text-center">
                <strong>{{ value.heading}}</strong>
            </h2>
            <hr>
        </div>

        {% if value.map %}
            <div class="col-md-8">
                <iframe width="100%" height="400" frameborder="0" scrolling="no" marginheight="0" marginwidth="0" src="{{ value.map }}"></iframe>
            </div>
        {% endif %}

        <div class="{% if not value.map %}col-md-offset-4 {% endif %}col-md-4">
            <p>Ansprechpartner:<br>
                <strong>{{ value.name }}</strong>
            </p>

            {% if value.phone %}
                <p>Telefon:<br>
                    <strong>{{ value.phone }}</strong>
                </p>
            {% endif %}

            {% if value.mail %}
                <p>E-Mail:<br>
                    <strong>{{ value.mail }}</strong>
                </p>
            {% endif %}

            {% if value.bank %}
                <p>Bankverbindung:<br>
                    <strong>{{ value.bank }}</strong>
                </p>
            {% endif %}
        </div>
    </div>
</div>
