{% extends "bootstrap_ui/bootstrap-skeleton.html" %}

{% load bootstrap_ui_tags %}
{% load i18n %}
{% load menu_tags %}
{% load static %}

{% block head-css %}
    {{ block.super }}

    <link href="{% static "css/business-casual.min.css" %}" media="screen" rel="stylesheet" type="text/css">
    <link href="{% static "css/texsite-business-casual.min.css" %}" media="screen" rel="stylesheet" type="text/css">
    <link href="https://fonts.googleapis.com/css?family=Open+Sans:300italic,400italic,600italic,700italic,800italic,400,300,600,700,800" rel="stylesheet" type="text/css">
    <link href="https://fonts.googleapis.com/css?family=Josefin+Slab:100,300,400,600,700,100italic,300italic,400italic,600italic,700italic" rel="stylesheet" type="text/css">
{% endblock %}

{% block head-title %}
    {{ page.title }} | {{ request.site.site_name }}
{% endblock %}

{% block body-content %}
    <div class="brand">{{ request.site.site_name }}</div>
    <div class="address-bar">{{ page.title }}</div>

    <!-- Navigation -->
    <nav class="navbar navbar-default" role="navigation">
        <div class="container">
            <!-- Brand and toggle get grouped for better mobile display -->
            <div class="navbar-header">
                <button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#navbar-collapse">
                    <span class="sr-only">{{ request.site.site_name }}</span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                </button>
                <!-- navbar-brand is hidden on larger screens, but visible when the menu is collapsed -->
                <a class="navbar-brand" href="/">{{ request.site.site_name }}</a>
            </div>
            <!-- Collect the nav links, forms, and other content for toggling -->
            <div class="collapse navbar-collapse" id="navbar-collapse">
                {% with handle="main_menu" %}
                    {% flat_menu handle template="texsitebusinesscasual/menus/"|add:handle|add:".html" %}
                {% endwith %}
            </div>
            <!-- /.navbar-collapse -->
        </div>
        <!-- /.container -->
    </nav>

    <div class="container">
        {% block business-casual-body-content %}{% endblock %}
    </div>

    <footer>
        {% container %}
            {% row %}
                <div class="col-sm-6 text-center">
                    {% with handle="footer_menu" %}
                        {% flat_menu handle template="texsitebusinesscasual/menus/"|add:handle|add:".html" %}
                    {% endwith %}
                </div>
                <div class="col-sm-6 text-center">
                    <p>{% trans "Copyright ©" %} {{ request.site.site_name }} {% now "Y" %}</p>
                </div>
            {% endrow %}
        {% endcontainer %}
    </footer>
{% endblock %}
